"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@medusajs/framework/utils");
const express_1 = __importDefault(require("express"));
const supertest_1 = __importDefault(require("supertest"));
const default_rate_limit_1 = require("../src/api/middlewares/default-rate-limit");
// Mock the cache service
const mockCacheService = {
    get: jest.fn(),
    set: jest.fn(),
    invalidate: jest.fn(),
};
const mockScope = {
    resolve: jest.fn().mockImplementation((module) => {
        if (module === utils_1.Modules.CACHE) {
            return mockCacheService;
        }
        return {};
    }),
};
const app = (0, express_1.default)();
app.use((req, res, next) => {
    req.scope = mockScope;
    next();
});
app.use((0, default_rate_limit_1.defaultRateLimit)({ limit: 2, window: 60 }));
app.get('/', (req, res) => {
    res.send('Hello World');
});
describe('defaultRateLimit Middleware', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it('should allow requests under the limit', async () => {
        mockCacheService.get.mockResolvedValueOnce(0);
        const response = await (0, supertest_1.default)(app).get('/');
        expect(response.status).toBe(200);
        expect(response.text).toBe('Hello World');
    });
    it('should block requests over the limit', async () => {
        mockCacheService.get.mockResolvedValueOnce(2);
        const response = await (0, supertest_1.default)(app).get('/');
        expect(response.status).toBe(429);
        expect(response.text).toBe('Too many requests, please try again later.');
    });
    it('should include rate limit headers when includeHeaders is true', async () => {
        app.use((0, default_rate_limit_1.defaultRateLimit)({ limit: 2, window: 60, includeHeaders: true }));
        mockCacheService.get.mockResolvedValueOnce(0);
        const response = await (0, supertest_1.default)(app).get('/');
        expect(response.headers['x-ratelimit-limit']).toBe('2');
        expect(response.headers['x-ratelimit-remaining']).toBe('1');
    });
    it('should not include rate limit headers when includeHeaders is false', async () => {
        const testApp = (0, express_1.default)();
        testApp.use((req, res, next) => {
            req.scope = mockScope;
            next();
        });
        testApp.use((0, default_rate_limit_1.defaultRateLimit)({ limit: 2, window: 60, includeHeaders: false }));
        testApp.get('/', (req, res) => {
            res.send('Hello World');
        });
        mockCacheService.get.mockResolvedValueOnce(0);
        const response = await (0, supertest_1.default)(testApp).get('/');
        expect(response.headers['x-ratelimit-limit']).toBeUndefined();
        expect(response.headers['x-ratelimit-remaining']).toBeUndefined();
    });
});
//# sourceMappingURL=default-rate-limit.spec.js.map